Logo ProcessCore

Data Type

Data file or selected fragment produced or consumed by processes. schema.org/MediaObject or File

Constructors

Constructor Description

Data(path, ?selector, ?selectorFormat, ?encodingFormat, ?additionalType, ?hasPart, ?additionalProperty)

Full Usage: Data(path, ?selector, ?selectorFormat, ?encodingFormat, ?additionalType, ?hasPart, ?additionalProperty)

Parameters:
    path : string
    ?selector : string
    ?selectorFormat : string
    ?encodingFormat : string
    ?additionalType : string
    ?hasPart : Data seq
    ?additionalProperty : Annotation seq

Returns: Data
path : string
?selector : string
?selectorFormat : string
?encodingFormat : string
?additionalType : string
?hasPart : Data seq
?additionalProperty : Annotation seq
Returns: Data

Instance members

Instance member Description

this.AddAdditionalProperty

Full Usage: this.AddAdditionalProperty

Parameters:

this.AddPart

Full Usage: this.AddPart

Parameters:
data : Data

this.AdditionalProperty

Full Usage: this.AdditionalProperty

Returns: ResizeArray<Annotation>
Returns: ResizeArray<Annotation>

this.AdditionalType

Full Usage: this.AdditionalType

Returns: string option

Decoration discriminator (e.g. "Raw Data")

Returns: string option

this.AllAnnotations

Full Usage: this.AllAnnotations

Parameters:
Returns: ResizeArray<Annotation>

All Annotations from all sources connected to this data node through the graph.

?scope : ResizeArray<Process>
Returns: ResizeArray<Annotation>

this.AllConnectedNodes

Full Usage: this.AllConnectedNodes

Parameters:
Returns: ResizeArray<IONode>

All IONodes connected to this data node through the graph.

?scope : ResizeArray<Process>
Returns: ResizeArray<IONode>

this.AllConnectedProcesses

Full Usage: this.AllConnectedProcesses

Parameters:
Returns: ResizeArray<Process>

All processes connected to this data node through the graph.

?scope : ResizeArray<Process>
Returns: ResizeArray<Process>

this.ConnectedData

Full Usage: this.ConnectedData

Parameters:
Returns: ResizeArray<Data>

All Data nodes connected to this data node through the graph.

?scope : ResizeArray<Process>
Returns: ResizeArray<Data>

this.ConnectedSamples

Full Usage: this.ConnectedSamples

Parameters:
Returns: ResizeArray<Sample>

All Sample nodes connected to this data node through the graph.

?scope : ResizeArray<Process>
Returns: ResizeArray<Sample>

this.DownstreamAnnotations

Full Usage: this.DownstreamAnnotations

Parameters:
    ?recipeName : string
    ?scope : ResizeArray<Process>

Returns: ResizeArray<Annotation>
?recipeName : string
?scope : ResizeArray<Process>
Returns: ResizeArray<Annotation>

this.DownstreamData

Full Usage: this.DownstreamData

Parameters:
Returns: ResizeArray<Data>
?scope : ResizeArray<Process>
Returns: ResizeArray<Data>

this.DownstreamNodes

Full Usage: this.DownstreamNodes

Parameters:
Returns: ResizeArray<IONode>
?scope : ResizeArray<Process>
Returns: ResizeArray<IONode>

this.DownstreamProcesses

Full Usage: this.DownstreamProcesses

Parameters:
Returns: ResizeArray<Process>
?scope : ResizeArray<Process>
Returns: ResizeArray<Process>

this.DownstreamSamples

Full Usage: this.DownstreamSamples

Parameters:
Returns: ResizeArray<Sample>
?scope : ResizeArray<Process>
Returns: ResizeArray<Sample>

this.EncodingFormat

Full Usage: this.EncodingFormat

Returns: string option

MIME type

Returns: string option

this.FinalNodes

Full Usage: this.FinalNodes

Parameters:
Returns: ResizeArray<IONode>
?scope : ResizeArray<Process>
Returns: ResizeArray<IONode>

this.HasPart

Full Usage: this.HasPart

Returns: ResizeArray<Data>
Returns: ResizeArray<Data>

this.InputOf

Full Usage: this.InputOf

Returns: HashSet<Process>

Processes for which this data node is an input (back-edge)

Returns: HashSet<Process>

this.IsFinalNode

Full Usage: this.IsFinalNode

Parameters:
Returns: bool
?scope : ResizeArray<Process>
Returns: bool

this.IsRootNode

Full Usage: this.IsRootNode

Parameters:
Returns: bool
?scope : ResizeArray<Process>
Returns: bool

this.Name

Full Usage: this.Name

Returns: string
Returns: string

this.OutputOf

Full Usage: this.OutputOf

Returns: HashSet<Process>

Processes for which this data node is an output (back-edge)

Returns: HashSet<Process>

this.Path

Full Usage: this.Path

Returns: string
Returns: string

this.PathsThrough

Full Usage: this.PathsThrough

Parameters:
Returns: ResizeArray<Path>

All maximal Paths that pass through this data node.

?scope : ResizeArray<Process>
Returns: ResizeArray<Path>

this.Processes

Full Usage: this.Processes

Parameters:
Returns: ResizeArray<Process>

All in-scope processes in which this data node appears as an input or output.

?scope : ResizeArray<Process>
Returns: ResizeArray<Process>

this.RecipeParameters

Full Usage: this.RecipeParameters

Parameters:
Returns: ResizeArray<FormalParameter>

All FormalParameters from recipes connected to this data node.

?scope : ResizeArray<Process>
Returns: ResizeArray<FormalParameter>

this.RemoveAdditionalProperty

Full Usage: this.RemoveAdditionalProperty

Parameters:

this.RemovePart

Full Usage: this.RemovePart

Parameters:
data : Data

this.RootNodes

Full Usage: this.RootNodes

Parameters:
Returns: ResizeArray<IONode>
?scope : ResizeArray<Process>
Returns: ResizeArray<IONode>

this.Selector

Full Usage: this.Selector

Returns: string option

Fragment selector

Returns: string option

this.SelectorFormat

Full Usage: this.SelectorFormat

Returns: string option

Formal description of the selector syntax (e.g. RFC 7111)

Returns: string option

this.TryGetPart

Full Usage: this.TryGetPart

Parameters:
    path : string

Returns: Data option
path : string
Returns: Data option

this.UpstreamAnnotations

Full Usage: this.UpstreamAnnotations

Parameters:
    ?recipeName : string
    ?scope : ResizeArray<Process>

Returns: ResizeArray<Annotation>
?recipeName : string
?scope : ResizeArray<Process>
Returns: ResizeArray<Annotation>

this.UpstreamData

Full Usage: this.UpstreamData

Parameters:
Returns: ResizeArray<Data>
?scope : ResizeArray<Process>
Returns: ResizeArray<Data>

this.UpstreamNodes

Full Usage: this.UpstreamNodes

Parameters:
Returns: ResizeArray<IONode>
?scope : ResizeArray<Process>
Returns: ResizeArray<IONode>

this.UpstreamProcesses

Full Usage: this.UpstreamProcesses

Parameters:
Returns: ResizeArray<Process>
?scope : ResizeArray<Process>
Returns: ResizeArray<Process>

this.UpstreamSamples

Full Usage: this.UpstreamSamples

Parameters:
Returns: ResizeArray<Sample>
?scope : ResizeArray<Process>
Returns: ResizeArray<Sample>

Type something to start searching.