Logo ProcessCore

ProcessCore.Helper Namespace

Modules Description

Identifier

This module contains helper functions to handle study/assay/investigation identifiers in an unsafe, forced way.

Ontology

Option

Path

Regex

This module contains unified regex patterns and matching functions to parse isa tab column headers to BuildingBlock information.

ResizeArray

Type something to start searching.