Study Module
Assay only contains "FileName" in isa.assay.xlsx. To unify naming in our model, on read-in we transform fileName to identifier and reverse for writing.
Functions and values
| Function or value |
Description
|
Full Usage:
Study.datamapFileNameFromIdentifier identifier
Parameters:
string
-
Any correct study identifier
Returns: string
|
On writing a xlsx file we unify our output to a relative path to ARC root. So: `studies/studyIdentifier/isa.investigation.xlsx`.
|
Full Usage:
Study.fileNameFromIdentifier identifier
Parameters:
string
-
Any correct study identifier
Returns: string
|
On writing a xlsx file we unify our output to a relative path to ARC root. So: `studies/studyIdentifier/isa.study.xlsx`.
|
Full Usage:
Study.identifierFromFileName fileName
Parameters:
string
-
FileName as written in isa.study.xlsx metadata sheet
Returns: string
|
On read-in the FileName can be any combination of "studies" (study folder name), studyIdentifier and "isa.study.xlsx" (the actual file name). This functions extracts studyIdentifier from any of these combinations and returns it.
|
Full Usage:
Study.tryDatamapFileNameFromIdentifier identifier
Parameters:
string
-
Any correct study identifier
Returns: string option
|
On writing a xlsx file we unify our output to a relative path to ARC root. So: `studies/studyIdentifier/isa.investigation.xlsx`.
|
Full Usage:
Study.tryFileNameFromIdentifier identifier
Parameters:
string
-
Any correct study identifier
Returns: string option
|
On writing a xlsx file we unify our output to a relative path to ARC root. So: `studies/studyIdentifier/isa.study.xlsx`.
|
Full Usage:
Study.tryIdentifierFromFileName fileName
Parameters:
string
-
FileName as written in isa.study.xlsx metadata sheet
Returns: string option
|
On read-in the FileName can be any combination of "studies" (study folder name), studyIdentifier and "isa.study.xlsx" (the actual file name). This functions extracts studyIdentifier from any of these combinations and returns it.
|
ProcessCore