Logo ProcessCore

Workflow Module

Workflow only contains "FileName" in isa.workflow.xlsx. To unify naming in our model, on read-in we transform fileName to identifier and reverse for writing.

Functions and values

Function or value Description

Workflow.cwlFileNameFromIdentifier identifier

Full Usage: Workflow.cwlFileNameFromIdentifier identifier

Parameters:
    identifier : string - Any correct workflow identifier

Returns: string

On writing a cwl file we unify our output to a relative path to ARC root. So: `workflows/workflowIdentifier/workflow.cwl`.

identifier : string

Any correct workflow identifier

Returns: string

Workflow.datamapFileNameFromIdentifier identifier

Full Usage: Workflow.datamapFileNameFromIdentifier identifier

Parameters:
    identifier : string - Any correct workflow identifier

Returns: string

On writing a xlsx file we unify our output to a relative path to ARC root. So: `workflows/workflowIdentifier/isa.datamap.xlsx`.

identifier : string

Any correct workflow identifier

Returns: string

Workflow.fileNameFromIdentifier identifier

Full Usage: Workflow.fileNameFromIdentifier identifier

Parameters:
    identifier : string - Any correct workflow identifier

Returns: string

On writing a xlsx file we unify our output to a relative path to ARC root. So: `workflows/workflowIdentifier/isa.workflow.xlsx`.

identifier : string

Any correct workflow identifier

Returns: string

Workflow.identifierFromFileName fileName

Full Usage: Workflow.identifierFromFileName fileName

Parameters:
    fileName : string - FileName as written in isa.workflow.xlsx metadata sheet

Returns: string

On read-in the FileName can be any combination of "workflows" (workflow folder name), workflowIdentifier and "isa.workflow.xlsx" (the actual file name). This functions extracts workflowIdentifier from any of these combinations and returns it.

fileName : string

FileName as written in isa.workflow.xlsx metadata sheet

Returns: string

Workflow.tryCwlFileNameFromIdentifier identifier

Full Usage: Workflow.tryCwlFileNameFromIdentifier identifier

Parameters:
    identifier : string - Any correct workflow identifier

Returns: string option

On writing a cwl file we unify our output to a relative path to ARC root. So: `workflows/workflowIdentifier/workflow.cwl`.

identifier : string

Any correct workflow identifier

Returns: string option

Workflow.tryDatamapFileNameFromIdentifier identifier

Full Usage: Workflow.tryDatamapFileNameFromIdentifier identifier

Parameters:
    identifier : string - Any correct workflow identifier

Returns: string option

On writing a xlsx file we unify our output to a relative path to ARC root. So: `workflows/workflowIdentifier/isa.datamap.xlsx`.

identifier : string

Any correct workflow identifier

Returns: string option

Workflow.tryFileNameFromIdentifier identifier

Full Usage: Workflow.tryFileNameFromIdentifier identifier

Parameters:
    identifier : string - Any correct workflow identifier

Returns: string option

On writing a xlsx file we unify our output to a relative path to ARC root. So: `workflows/workflowIdentifier/isa.workflow.xlsx`.

identifier : string

Any correct workflow identifier

Returns: string option

Workflow.tryIdentifierFromFileName fileName

Full Usage: Workflow.tryIdentifierFromFileName fileName

Parameters:
    fileName : string - FileName as written in isa.workflow.xlsx metadata sheet

Returns: string option

On read-in the FileName can be any combination of "workflows" (workflow folder name), workflowIdentifier and "isa.workflow.xlsx" (the actual file name). This functions extracts workflowIdentifier from any of these combinations and returns it.

fileName : string

FileName as written in isa.workflow.xlsx metadata sheet

Returns: string option

Type something to start searching.