Logo ProcessCore

ActivePatterns Module

Active patterns

Active pattern Description

(|AutoGeneratedTableName|_|) input

Full Usage: (|AutoGeneratedTableName|_|) input

Parameters:
    input : string

Returns: int option

Matches auto-generated readable table names. Mainly used in ArcAssay.addTable(). Default tables will get such a name. Will match "New Table 10" and return the number `10`.

input : string
Returns: int option

(|CharacteristicColumnHeader|_|) input

Full Usage: (|CharacteristicColumnHeader|_|) input

Parameters:
    input : string

Returns: string option

Matches a "Characteristic [Term]" or "Characteristics [Term]" or "Characteristics Value [Term]" column header and returns the Term string.

input : string
Returns: string option

(|Comment|_|) input

Full Usage: (|Comment|_|) input

Parameters:
    input : string

Returns: string option
input : string
Returns: string option

(|ComponentColumnHeader|_|) input

Full Usage: (|ComponentColumnHeader|_|) input

Parameters:
    input : string

Returns: string option

Matches a "Component [Term]" or "Component Value [Term]" column header and returns the Term string.

input : string
Returns: string option

(|FactorColumnHeader|_|) input

Full Usage: (|FactorColumnHeader|_|) input

Parameters:
    input : string

Returns: string option

Matches a "Factor [Term]" or "Factor Value [Term]" column header and returns the Term string.

input : string
Returns: string option

(|InputColumnHeader|_|) input

Full Usage: (|InputColumnHeader|_|) input

Parameters:
    input : string

Returns: string option

Matches a "Input [InputType]" column header and returns the InputType as string.

input : string
Returns: string option

(|OutputColumnHeader|_|) input

Full Usage: (|OutputColumnHeader|_|) input

Parameters:
    input : string

Returns: string option

Matches a "Output [OutputType]" column header and returns the OutputType as string.

input : string
Returns: string option

(|ParameterColumnHeader|_|) input

Full Usage: (|ParameterColumnHeader|_|) input

Parameters:
    input : string

Returns: string option

Matches a "Parameter [Term]" or "Parameter Value [Term]" column header and returns the Term string.

input : string
Returns: string option

(|ReferenceColumnHeader|_|) input

Full Usage: (|ReferenceColumnHeader|_|) input

Parameters:
    input : string

Returns: (type) option

Matches any column header starting with some text, followed by one whitespace and a term name inside squared brackets.

input : string
Returns: (type) option

(|Regex|_|) pattern input

Full Usage: (|Regex|_|) pattern input

Parameters:
    pattern : string
    input : string

Returns: Match option

Matches, if the input string matches the given regex pattern.

pattern : string
input : string
Returns: Match option

(|TANColumnHeader|_|) input

Full Usage: (|TANColumnHeader|_|) input

Parameters:
    input : string

Returns: (type) option

Matches a "Term Accession Number (ShortTerm)" column header and returns the ShortTerm as Term Source Ref and Annotation Number. Example: "Term Accession Number (MS:1003022)" --> term source ref: "MS"; annotation number: "1003022"

input : string
Returns: (type) option

(|TSRColumnHeader|_|) input

Full Usage: (|TSRColumnHeader|_|) input

Parameters:
    input : string

Returns: (type) option

Matches a "Term Source REF (ShortTerm)" column header and returns the ShortTerm as Term Source Ref and Annotation Number. Example: "Term Source REF (MS:1003022)" --> term source ref: "MS"; annotation number: "1003022"

input : string
Returns: (type) option

(|TermAnnotationShort|_|) input

Full Usage: (|TermAnnotationShort|_|) input

Parameters:
    input : string

Returns: (type) option

Matches a short term string and returns the term source ref and the annotation number strings. Example: "MS:1003022" --> term source ref: "MS"; annotation number: "1003022"

input : string
Returns: (type) option

(|TermAnnotation|_|) input

Full Usage: (|TermAnnotation|_|) input

Parameters:
    input : string

Returns: (type) option

Matches a term string (either short or URI) and returns the term source ref and the annotation number strings. Example 1: "MS:1003022" --> term source ref: "MS"; annotation number: "1003022" Example 2: "http://purl.obolibrary.org/obo/MS_1003022" --> term source ref: "MS"; annotation number: "1003022"

input : string
Returns: (type) option

(|TermColumn|_|) input

Full Usage: (|TermColumn|_|) input

Parameters:
    input : string

Returns: (type) option

Matches any column header starting with some text, followed by one whitespace and a term name inside squared brackets.

input : string
Returns: (type) option

(|UnitColumnHeader|_|) input

Full Usage: (|UnitColumnHeader|_|) input

Parameters:
    input : string

Returns: string option

Matches a "Unit" column header.

input : string
Returns: string option

Type something to start searching.