Logo ProcessCore

Pattern Module

Nested modules

Modules Description

MatchGroups

Functions and values

Function or value Description

AutoGeneratedTableName

Full Usage: AutoGeneratedTableName

Returns: string

This pattern is used to match auto-generated table names. Mainly used in ArcAssay.addTable(). Default tables will get such a name. Will match "New Table 10" and will capture the number as `number` group.

Returns: string

CommentPattern

Full Usage: CommentPattern

Returns: string

This pattern is used to match Comment column and capture the comment key as `commentKey` group.

Returns: string

ExcelNumberFormat

Full Usage: ExcelNumberFormat

Returns: string

Used to get unit name from Excel numberFormat: 0.00 "degree Celsius" --> degree Celsius

Returns: string

IOTypePattern

Full Usage: IOTypePattern

Returns: string

This pattern is used to match both Input and Output columns and capture the IOType as `iotype` group.

Returns: string

IdPattern

Full Usage: IdPattern

Returns: string

This pattern is only used to remove any leftover #id attributes from previous Swate version. `"Parameter [biological replicate#2]"` This #id is deprecated but the pattern can still be used to remove any from files. Was deprecated before 2023.

Returns: string

InputPattern

Full Usage: InputPattern

Returns: string

This pattern is used to match Input column and capture the IOType as `iotype` group.

Returns: string

OutputPattern

Full Usage: OutputPattern

Returns: string

This pattern is used to match Output column and capture the IOType as `iotype` group.

Returns: string

ReferenceColumnPattern

Full Usage: ReferenceColumnPattern

Returns: string

Hits Term Source REF and Term Accession Number column headers Example 1: "Term Source REF (MS:1003022)" Example 2: "Term Accession Number (MS:1003022)" the id part "MS:1003022" is captured as `id` group.

Returns: string

SquaredBracketsTermNamePattern

Full Usage: SquaredBracketsTermNamePattern

Returns: string

This pattern captures characters between squared brackets, without id: Parameter [biological replicate#2] -> [biological replicate] TODO: Could be redesigned to use capture groups, then it could return inner without brackets

Returns: string

TermAccessionNumberColumnPattern

Full Usage: TermAccessionNumberColumnPattern

Returns: string

Hits Term Source REF column header Example 1: "Term Accession Number (MS:1003022)" the id part "MS:1003022" is captured as `id` group.

Returns: string

TermAnnotationShortPattern

Full Usage: TermAnnotationShortPattern

Returns: string

Hits term accession, without id: ENVO:01001831

Returns: string

TermAnnotationURIPattern

Full Usage: TermAnnotationURIPattern

Returns: string

Regex pattern is designed to hit only Foundry-compliant URIs.

Returns: string

TermAnnotationURIPattern_MS_RO_PO

Full Usage: TermAnnotationURIPattern_MS_RO_PO

Returns: string

Watch this closely, this could hit some edge cases we do not want to cover.

Returns: string

TermAnnotationURIPattern_lessRestrictive

Full Usage: TermAnnotationURIPattern_lessRestrictive

Returns: string

Watch this closely, this could hit some edge cases we do not want to cover.

Returns: string

TermAnnotationURIPattern_stringTSR

Full Usage: TermAnnotationURIPattern_stringTSR

Returns: string
Returns: string

TermColumnPattern

Full Usage: TermColumnPattern

Returns: string

This pattern matches any column header starting with some text, followed by one whitespace and a term name inside squared brackets. Captures column type as named group: "termcolumntype" (e.g. Component, Characteristic .. ). Captures term name as named group: "termname" (e.g. instrument model). Exmp. 1: Parameter [instrument model] --> termcolumntype: Parameter; termname: instrument model Exmp. 2: Characteristic [species] --> termcolumntype: Characteristic; termname: species

Returns: string

TermSourceREFColumnPattern

Full Usage: TermSourceREFColumnPattern

Returns: string

Hits Term Accession Number column header Example 1: "Term Source REF (MS:1003022)" the id part "MS:1003022" is captured as `id` group.

Returns: string

UnitPattern

Full Usage: UnitPattern

Returns: string

Hits Unit column header

Returns: string

handleGroupPatterns pattern

Full Usage: handleGroupPatterns pattern

Parameters:
    pattern : string

Returns: string
pattern : string
Returns: string

Type something to start searching.