Logo ProcessCore

Material Type

Input or output biological, chemical, or digital material in the process graph. bioschemas.org/Sample

Constructors

Constructor Description

Material(name, ?additionalType, ?additionalProperty)

Full Usage: Material(name, ?additionalType, ?additionalProperty)

Parameters:
    name : string
    ?additionalType : string
    ?additionalProperty : PropertyValue seq

Returns: Material
name : string
?additionalType : string
?additionalProperty : PropertyValue seq
Returns: Material

Instance members

Instance member Description

this.AddAdditionalProperty

Full Usage: this.AddAdditionalProperty

Parameters:

this.AdditionalProperty

Full Usage: this.AdditionalProperty

Returns: ResizeArray<PropertyValue>
Returns: ResizeArray<PropertyValue>

this.AdditionalType

Full Usage: this.AdditionalType

Returns: string option

Decoration discriminator (e.g. "Sample", "Source")

Returns: string option

this.AllConnectedNodes

Full Usage: this.AllConnectedNodes

Parameters:
Returns: ResizeArray<IONode>

All IONodes connected to this material through the graph.

?scope : ResizeArray<LabProcess>
Returns: ResizeArray<IONode>

this.AllConnectedProcesses

Full Usage: this.AllConnectedProcesses

Parameters:
Returns: ResizeArray<LabProcess>

All processes connected to this material through the graph.

?scope : ResizeArray<LabProcess>
Returns: ResizeArray<LabProcess>

this.AllPropertyValues

Full Usage: this.AllPropertyValues

Parameters:
Returns: ResizeArray<PropertyValue>

All PropertyValues from all sources connected to this material through the graph.

?scope : ResizeArray<LabProcess>
Returns: ResizeArray<PropertyValue>

this.ConnectedData

Full Usage: this.ConnectedData

Parameters:
Returns: ResizeArray<Data>

All Data nodes connected to this material through the graph.

?scope : ResizeArray<LabProcess>
Returns: ResizeArray<Data>

this.ConnectedMaterials

Full Usage: this.ConnectedMaterials

Parameters:
Returns: ResizeArray<Material>

All Material nodes connected to this material through the graph.

?scope : ResizeArray<LabProcess>
Returns: ResizeArray<Material>

this.DownstreamData

Full Usage: this.DownstreamData

Parameters:
Returns: ResizeArray<Data>
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<Data>

this.DownstreamMaterials

Full Usage: this.DownstreamMaterials

Parameters:
Returns: ResizeArray<Material>
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<Material>

this.DownstreamNodes

Full Usage: this.DownstreamNodes

Parameters:
Returns: ResizeArray<IONode>
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<IONode>

this.DownstreamProcesses

Full Usage: this.DownstreamProcesses

Parameters:
Returns: ResizeArray<LabProcess>
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<LabProcess>

this.DownstreamPropertyValues

Full Usage: this.DownstreamPropertyValues

Parameters:
    ?protocolName : string
    ?scope : ResizeArray<LabProcess>

Returns: ResizeArray<PropertyValue>
?protocolName : string
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<PropertyValue>

this.FinalNodes

Full Usage: this.FinalNodes

Parameters:
Returns: ResizeArray<IONode>
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<IONode>

this.InputOf

Full Usage: this.InputOf

Returns: HashSet<LabProcess>

Processes for which this material is an input (back-edge)

Returns: HashSet<LabProcess>

this.IsFinalNode

Full Usage: this.IsFinalNode

Parameters:
Returns: bool
?scope : ResizeArray<LabProcess>
Returns: bool

this.IsRootNode

Full Usage: this.IsRootNode

Parameters:
Returns: bool
?scope : ResizeArray<LabProcess>
Returns: bool

this.Name

Full Usage: this.Name

Returns: string
Returns: string

this.OutputOf

Full Usage: this.OutputOf

Returns: HashSet<LabProcess>

Processes for which this material is an output (back-edge)

Returns: HashSet<LabProcess>

this.PathsThrough

Full Usage: this.PathsThrough

Parameters:
Returns: ResizeArray<Path>

All maximal Paths that pass through this material.

?scope : ResizeArray<LabProcess>
Returns: ResizeArray<Path>

this.Processes

Full Usage: this.Processes

Parameters:
Returns: ResizeArray<LabProcess>

All in-scope processes in which this material appears as an input or output.

?scope : ResizeArray<LabProcess>
Returns: ResizeArray<LabProcess>

this.ProtocolParameters

Full Usage: this.ProtocolParameters

Parameters:
Returns: ResizeArray<FormalParameter>

All FormalParameters from protocols connected to this material.

?scope : ResizeArray<LabProcess>
Returns: ResizeArray<FormalParameter>

this.RemoveAdditionalProperty

Full Usage: this.RemoveAdditionalProperty

Parameters:

this.RootNodes

Full Usage: this.RootNodes

Parameters:
Returns: ResizeArray<IONode>
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<IONode>

this.UpstreamData

Full Usage: this.UpstreamData

Parameters:
Returns: ResizeArray<Data>
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<Data>

this.UpstreamMaterials

Full Usage: this.UpstreamMaterials

Parameters:
Returns: ResizeArray<Material>
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<Material>

this.UpstreamNodes

Full Usage: this.UpstreamNodes

Parameters:
Returns: ResizeArray<IONode>
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<IONode>

this.UpstreamProcesses

Full Usage: this.UpstreamProcesses

Parameters:
Returns: ResizeArray<LabProcess>
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<LabProcess>

this.UpstreamPropertyValues

Full Usage: this.UpstreamPropertyValues

Parameters:
    ?protocolName : string
    ?scope : ResizeArray<LabProcess>

Returns: ResizeArray<PropertyValue>
?protocolName : string
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<PropertyValue>

Type something to start searching.