Logo ProcessCore

Sample Type

Input or output biological, chemical, or digital sample in the process graph. bioschemas.org/Sample

Constructors

Constructor Description

Sample(name, ?additionalType, ?additionalProperty)

Full Usage: Sample(name, ?additionalType, ?additionalProperty)

Parameters:
    name : string
    ?additionalType : string
    ?additionalProperty : Annotation seq

Returns: Sample
name : string
?additionalType : string
?additionalProperty : Annotation seq
Returns: Sample

Instance members

Instance member Description

this.AddAdditionalProperty

Full Usage: this.AddAdditionalProperty

Parameters:

this.AdditionalProperty

Full Usage: this.AdditionalProperty

Returns: ResizeArray<Annotation>
Returns: ResizeArray<Annotation>

this.AdditionalType

Full Usage: this.AdditionalType

Returns: string option

Decoration discriminator (e.g. "Sample", "Source")

Returns: string option

this.AllAnnotations

Full Usage: this.AllAnnotations

Parameters:
Returns: ResizeArray<Annotation>

All Annotations from all sources connected to this sample through the graph.

?scope : ResizeArray<Process>
Returns: ResizeArray<Annotation>

this.AllConnectedNodes

Full Usage: this.AllConnectedNodes

Parameters:
Returns: ResizeArray<IONode>

All IONodes connected to this sample through the graph.

?scope : ResizeArray<Process>
Returns: ResizeArray<IONode>

this.AllConnectedProcesses

Full Usage: this.AllConnectedProcesses

Parameters:
Returns: ResizeArray<Process>

All processes connected to this sample through the graph.

?scope : ResizeArray<Process>
Returns: ResizeArray<Process>

this.ConnectedData

Full Usage: this.ConnectedData

Parameters:
Returns: ResizeArray<Data>

All Data nodes connected to this sample through the graph.

?scope : ResizeArray<Process>
Returns: ResizeArray<Data>

this.ConnectedSamples

Full Usage: this.ConnectedSamples

Parameters:
Returns: ResizeArray<Sample>

All Sample nodes connected to this sample through the graph.

?scope : ResizeArray<Process>
Returns: ResizeArray<Sample>

this.DownstreamAnnotations

Full Usage: this.DownstreamAnnotations

Parameters:
    ?recipeName : string
    ?scope : ResizeArray<Process>

Returns: ResizeArray<Annotation>
?recipeName : string
?scope : ResizeArray<Process>
Returns: ResizeArray<Annotation>

this.DownstreamData

Full Usage: this.DownstreamData

Parameters:
Returns: ResizeArray<Data>
?scope : ResizeArray<Process>
Returns: ResizeArray<Data>

this.DownstreamNodes

Full Usage: this.DownstreamNodes

Parameters:
Returns: ResizeArray<IONode>
?scope : ResizeArray<Process>
Returns: ResizeArray<IONode>

this.DownstreamProcesses

Full Usage: this.DownstreamProcesses

Parameters:
Returns: ResizeArray<Process>
?scope : ResizeArray<Process>
Returns: ResizeArray<Process>

this.DownstreamSamples

Full Usage: this.DownstreamSamples

Parameters:
Returns: ResizeArray<Sample>
?scope : ResizeArray<Process>
Returns: ResizeArray<Sample>

this.FinalNodes

Full Usage: this.FinalNodes

Parameters:
Returns: ResizeArray<IONode>
?scope : ResizeArray<Process>
Returns: ResizeArray<IONode>

this.InputOf

Full Usage: this.InputOf

Returns: HashSet<Process>

Processes for which this sample is an input (back-edge)

Returns: HashSet<Process>

this.IsFinalNode

Full Usage: this.IsFinalNode

Parameters:
Returns: bool
?scope : ResizeArray<Process>
Returns: bool

this.IsRootNode

Full Usage: this.IsRootNode

Parameters:
Returns: bool
?scope : ResizeArray<Process>
Returns: bool

this.Name

Full Usage: this.Name

Returns: string
Returns: string

this.OutputOf

Full Usage: this.OutputOf

Returns: HashSet<Process>

Processes for which this sample is an output (back-edge)

Returns: HashSet<Process>

this.PathsThrough

Full Usage: this.PathsThrough

Parameters:
Returns: ResizeArray<Path>

All maximal Paths that pass through this sample.

?scope : ResizeArray<Process>
Returns: ResizeArray<Path>

this.Processes

Full Usage: this.Processes

Parameters:
Returns: ResizeArray<Process>

All in-scope processes in which this sample appears as an input or output.

?scope : ResizeArray<Process>
Returns: ResizeArray<Process>

this.RecipeParameters

Full Usage: this.RecipeParameters

Parameters:
Returns: ResizeArray<FormalParameter>

All FormalParameters from recipes connected to this sample.

?scope : ResizeArray<Process>
Returns: ResizeArray<FormalParameter>

this.RemoveAdditionalProperty

Full Usage: this.RemoveAdditionalProperty

Parameters:

this.RootNodes

Full Usage: this.RootNodes

Parameters:
Returns: ResizeArray<IONode>
?scope : ResizeArray<Process>
Returns: ResizeArray<IONode>

this.UpstreamAnnotations

Full Usage: this.UpstreamAnnotations

Parameters:
    ?recipeName : string
    ?scope : ResizeArray<Process>

Returns: ResizeArray<Annotation>
?recipeName : string
?scope : ResizeArray<Process>
Returns: ResizeArray<Annotation>

this.UpstreamData

Full Usage: this.UpstreamData

Parameters:
Returns: ResizeArray<Data>
?scope : ResizeArray<Process>
Returns: ResizeArray<Data>

this.UpstreamNodes

Full Usage: this.UpstreamNodes

Parameters:
Returns: ResizeArray<IONode>
?scope : ResizeArray<Process>
Returns: ResizeArray<IONode>

this.UpstreamProcesses

Full Usage: this.UpstreamProcesses

Parameters:
Returns: ResizeArray<Process>
?scope : ResizeArray<Process>
Returns: ResizeArray<Process>

this.UpstreamSamples

Full Usage: this.UpstreamSamples

Parameters:
Returns: ResizeArray<Sample>
?scope : ResizeArray<Process>
Returns: ResizeArray<Sample>

Type something to start searching.