CompositeColumn Module
Functions and values
| Function or value |
Description
|
Full Usage:
fixDeprecatedIOHeader stringCellCol
Parameters:
string[]
Returns: string[]
|
Checks if the column header is a deprecated IO Header. If so, fixes it.
The old format of IO Headers was only the type of IO so, e.g. "Source Name" or "Raw Data File".
A "Source Name" column will now be mapped to the propper "Input [Source Name]", and all other IO types will be mapped to "Output [
|
|
|
Full Usage:
fromStringCellColumns columns
Parameters:
string[] array
Returns: CompositeColumn
|
|
Full Usage:
stringCellColumnsOfFsColumns columns
Parameters:
FsColumn[]
Returns: string[][]
|
|
|
|
Full Usage:
toStringCellColumns column
Parameters:
CompositeColumn
Returns: string list list
|
|
ProcessCore