DatamapTable Module
Functions and values
| Function or value |
Description
|
Full Usage:
composeColumns columns
Parameters:
FsColumn seq
Returns: ResizeArray<DataContext>
|
Groups and parses a collection of single columns into the according ISA composite columns
|
Full Usage:
datamapTablePrefix
Returns: string
|
|
|
|
Full Usage:
helperColumnStrings
Returns: string list
|
|
|
|
Full Usage:
tryDataContextsFromFsWorksheet sheet
Parameters:
FsWorksheet
Returns: ResizeArray<DataContext> option
|
|
|
Returns the annotation table of the worksheet if it exists, else returns None
|
|
Returns the protocol described by the headers and a function for parsing the values of the matrix to the processes of this protocol
|
ProcessCore