Logo ProcessCore

DefinedTerm Module

Functions and values

Function or value Description

fromAggregatedStrings separator terms source accessions

Full Usage: fromAggregatedStrings separator terms source accessions

Parameters:
    separator : char
    terms : string
    source : string
    accessions : string

Returns: ResizeArray<DefinedTerm>

Returns a list of ISAJson OntologyAnnotation objects from ISATab aggregated strings

separator : char
terms : string
source : string
accessions : string
Returns: ResizeArray<DefinedTerm>

getLengthOfAggregatedStrings separator strings

Full Usage: getLengthOfAggregatedStrings separator strings

Parameters:
    separator : char
    strings : string[]

Returns: int

Returns the length of a subpropertylist from the aggregated strings In ISATab format, some subproperties which are stored as lists in ISAJson are stored as semicolon delimited tables These strings should either contain the same number of semicolon delimited elements or be empty.

separator : char
strings : string[]
Returns: int

toAggregatedStrings separator oas

Full Usage: toAggregatedStrings separator oas

Parameters:
Returns: (type)

Returns the aggregated ISATab OntologyAnnotation Name, ontology source and Accession number from a list of ISAJson OntologyAnnotation objects

separator : char
oas : DefinedTerm seq
Returns: (type)

Type something to start searching.