Seq Module
Functions and values
| Function or value |
Description
|
Full Usage:
trySkip i s
Parameters:
int
s : 'a seq
Returns: 'a seq option
Type parameters: 'a |
If at least i values exist in seq a, builds a new array that contains the elements of the given seq, exluding the first i elements
|
ProcessCore