Table Module
Types
| Type | Description |
|
|
Functions and values
| Function or value |
Description
|
Full Usage:
annotationTablePrefix
Returns: string
|
|
|
|
|
|
Full Usage:
composeColumns stringCellColumns
Parameters:
string[] array
Returns: CompositeColumn[]
|
Groups and parses a collection of single columns into the according ISA composite columns
|
Full Usage:
groupColumnsByHeader stringCellColumns
Parameters:
string[] array
Returns: string[] array array
|
|
Full Usage:
helperColumnStrings
Returns: string list
|
|
Full Usage:
toFsWorksheet index table
Parameters:
int option
table : Table
Returns: FsWorksheet
|
|
|
Returns the annotation table of the worksheet if it exists, else returns None
|
Full Usage:
tryFromFsWorksheet ds sheet
Parameters:
Dataset
sheet : FsWorksheet
Returns: Table option
|
Returns the protocol described by the headers and a function for parsing the values of the matrix to the processes of this protocol
|
ProcessCore