Logo ProcessCore

DataRow Type

Row of the data table — a digital data item identified by a path and optional selector, participating as input or output of a LabProcessRow.

Constructors

Constructor Description

DataRow(Id, Type, Path, ?AdditionalType, ?Selector, ?SelectorFormat, ?EncodingFormat)

Full Usage: DataRow(Id, Type, Path, ?AdditionalType, ?Selector, ?SelectorFormat, ?EncodingFormat)

Parameters:
    Id : string
    Type : string
    Path : string
    ?AdditionalType : string
    ?Selector : string
    ?SelectorFormat : string
    ?EncodingFormat : string

Returns: DataRow
Id : string
Type : string
Path : string
?AdditionalType : string
?Selector : string
?SelectorFormat : string
?EncodingFormat : string
Returns: DataRow

Instance members

Instance member Description

this.AdditionalType

Full Usage: this.AdditionalType

Returns: string option

Optional refinement of Type.

Returns: string option

this.EncodingFormat

Full Usage: this.EncodingFormat

Returns: string option

Optional MIME type / encoding format.

Returns: string option

this.Id

Full Usage: this.Id

Returns: string

Primary key.

Returns: string

this.Path

Full Usage: this.Path

Returns: string

Path/URI of the data item.

Returns: string

this.Selector

Full Usage: this.Selector

Returns: string option

Optional selector for a sub-region of the data.

Returns: string option

this.SelectorFormat

Full Usage: this.SelectorFormat

Returns: string option

Optional format identifier for Selector.

Returns: string option

this.Type

Full Usage: this.Type

Returns: string

Type discriminator.

Returns: string

Static members

Static member Description

DataRow.create (Id, Type, Path, ?AdditionalType, ?Selector, ?SelectorFormat, ?EncodingFormat)

Full Usage: DataRow.create (Id, Type, Path, ?AdditionalType, ?Selector, ?SelectorFormat, ?EncodingFormat)

Parameters:
    Id : string
    Type : string
    Path : string
    ?AdditionalType : string
    ?Selector : string
    ?SelectorFormat : string
    ?EncodingFormat : string

Returns: DataRow

Named-argument constructor exposed to JavaScript and Python callers.

Id : string
Type : string
Path : string
?AdditionalType : string
?Selector : string
?SelectorFormat : string
?EncodingFormat : string
Returns: DataRow

Type something to start searching.