Logo ProcessCore

RecipeRow Type

Row of the recipe table — a reusable protocol definition that can be executed by one or more ProcessRow instances and parameterised through ProtocolParameterRow entries.

Constructors

Constructor Description

RecipeRow(Id, Type, ?AdditionalType, ?Name, ?Description, ?Version, ?Url, ?IntendedUseId, ?IntendedUseText)

Full Usage: RecipeRow(Id, Type, ?AdditionalType, ?Name, ?Description, ?Version, ?Url, ?IntendedUseId, ?IntendedUseText)

Parameters:
    Id : string
    Type : string
    ?AdditionalType : string
    ?Name : string
    ?Description : string
    ?Version : string
    ?Url : string
    ?IntendedUseId : string
    ?IntendedUseText : string

Returns: RecipeRow
Id : string
Type : string
?AdditionalType : string
?Name : string
?Description : string
?Version : string
?Url : string
?IntendedUseId : string
?IntendedUseText : string
Returns: RecipeRow

Instance members

Instance member Description

this.AdditionalType

Full Usage: this.AdditionalType

Returns: string option

Optional refinement of Type.

Returns: string option

this.Description

Full Usage: this.Description

Returns: string option

Optional free-form description.

Returns: string option

this.Id

Full Usage: this.Id

Returns: string

Primary key.

Returns: string

this.IntendedUseId

Full Usage: this.IntendedUseId

Returns: string option

Optional id of a defined term describing the intended use.

Returns: string option

this.IntendedUseText

Full Usage: this.IntendedUseText

Returns: string option

Optional free-form intended-use description.

Returns: string option

this.Name

Full Usage: this.Name

Returns: string option

Optional protocol name.

Returns: string option

this.Type

Full Usage: this.Type

Returns: string

Type discriminator.

Returns: string

this.Url

Full Usage: this.Url

Returns: string option

Optional canonical URL.

Returns: string option

this.Version

Full Usage: this.Version

Returns: string option

Optional version identifier.

Returns: string option

Static members

Static member Description

RecipeRow.create (Id, Type, ?AdditionalType, ?Name, ?Description, ?Version, ?Url, ?IntendedUseId, ?IntendedUseText)

Full Usage: RecipeRow.create (Id, Type, ?AdditionalType, ?Name, ?Description, ?Version, ?Url, ?IntendedUseId, ?IntendedUseText)

Parameters:
    Id : string
    Type : string
    ?AdditionalType : string
    ?Name : string
    ?Description : string
    ?Version : string
    ?Url : string
    ?IntendedUseId : string
    ?IntendedUseText : string

Returns: RecipeRow

Named-argument constructor exposed to JavaScript and Python callers.

Id : string
Type : string
?AdditionalType : string
?Name : string
?Description : string
?Version : string
?Url : string
?IntendedUseId : string
?IntendedUseText : string
Returns: RecipeRow

Type something to start searching.