Logo ProcessCore

CompositeHeader Type

Typed column header. Carries the column role and, for annotation columns, the ontology term identifying what is being described.

Union cases

Union case Description

Characteristic DefinedTerm

Full Usage: Characteristic DefinedTerm

Parameters:
Item : DefinedTerm

Comment string

Full Usage: Comment string

Parameters:
    Item : string

Item : string

Component DefinedTerm

Full Usage: Component DefinedTerm

Parameters:
Item : DefinedTerm

Date

Full Usage: Date

Factor DefinedTerm

Full Usage: Factor DefinedTerm

Parameters:
Item : DefinedTerm

FreeText string

Full Usage: FreeText string

Parameters:
    Item : string

Item : string

Input IOType

Full Usage: Input IOType

Parameters:
Item : IOType

Output IOType

Full Usage: Output IOType

Parameters:
Item : IOType

Parameter DefinedTerm

Full Usage: Parameter DefinedTerm

Parameters:
Item : DefinedTerm

Performer

Full Usage: Performer

ProtocolDescription

Full Usage: ProtocolDescription

ProtocolREF

Full Usage: ProtocolREF

ProtocolType

Full Usage: ProtocolType

ProtocolUri

Full Usage: ProtocolUri

ProtocolVersion

Full Usage: ProtocolVersion

Instance members

Instance member Description

this.GetColumnAccessionShort

Full Usage: this.GetColumnAccessionShort

Returns: string

This function gets the associated term accession for term columns.

Returns: string

this.GetFeaturedColumnAccession

Full Usage: this.GetFeaturedColumnAccession

Returns: string

This function gets the associated term accession for featured columns. It contains the hardcoded term accessions.

Returns: string

this.IsCharacteristic

Full Usage: this.IsCharacteristic

Returns: bool
Returns: bool

this.IsComment

Full Usage: this.IsComment

Returns: bool
Returns: bool

this.IsComponent

Full Usage: this.IsComponent

Returns: bool
Returns: bool

this.IsCvParamColumn

Full Usage: this.IsCvParamColumn

Returns: bool
Returns: bool

this.IsDataColumn

Full Usage: this.IsDataColumn

Returns: bool
Returns: bool

this.IsDate

Full Usage: this.IsDate

Returns: bool
Returns: bool

this.IsFactor

Full Usage: this.IsFactor

Returns: bool
Returns: bool

this.IsFeaturedColumn

Full Usage: this.IsFeaturedColumn

Returns: bool

Is true if the Building Block type is a FeaturedColumn. A FeaturedColumn can be abstracted by Parameter/Factor/Characteristic and describes one common usecase of either. Such a block will contain TSR and TAN and can be used for directed Term search.

Returns: bool

this.IsFreeText

Full Usage: this.IsFreeText

Returns: bool
Returns: bool

this.IsIOType

Full Usage: this.IsIOType

Returns: bool
Returns: bool

this.IsInput

Full Usage: this.IsInput

Returns: bool
Returns: bool

this.IsOutput

Full Usage: this.IsOutput

Returns: bool
Returns: bool

this.IsParameter

Full Usage: this.IsParameter

Returns: bool
Returns: bool

this.IsPerformer

Full Usage: this.IsPerformer

Returns: bool
Returns: bool

this.IsProtocolDescription

Full Usage: this.IsProtocolDescription

Returns: bool
Returns: bool

this.IsProtocolREF

Full Usage: this.IsProtocolREF

Returns: bool
Returns: bool

this.IsProtocolType

Full Usage: this.IsProtocolType

Returns: bool
Returns: bool

this.IsProtocolUri

Full Usage: this.IsProtocolUri

Returns: bool
Returns: bool

this.IsProtocolVersion

Full Usage: this.IsProtocolVersion

Returns: bool
Returns: bool

this.IsSingleColumn

Full Usage: this.IsSingleColumn

Returns: bool

Is true if the Building Block type is parsed to a single column. This can be any input, output column, as well as for example: `ProtocolREF` and `Performer` with FreeText body cells.

Returns: bool

this.IsTermColumn

Full Usage: this.IsTermColumn

Returns: bool

Is true if this Building Block type is a TermColumn. The name "TermColumn" refers to all columns with the syntax "Parameter/Factor/etc [TERM-NAME]" and featured columns such as Protocol Type as these are also represented as a triplet of MainColumn-TSR-TAN.

Returns: bool

this.IsUnique

Full Usage: this.IsUnique

Returns: bool
Returns: bool

this.TryIOType

Full Usage: this.TryIOType

Returns: IOType option
Returns: IOType option

this.TryInput

Full Usage: this.TryInput

Returns: IOType option
Returns: IOType option

this.TryOutput

Full Usage: this.TryOutput

Returns: IOType option
Returns: IOType option

this.isCharacteristic

Full Usage: this.isCharacteristic

Returns: bool
Returns: bool

this.isComment

Full Usage: this.isComment

Returns: bool
Returns: bool

this.isComponent

Full Usage: this.isComponent

Returns: bool
Returns: bool

this.isDate

Full Usage: this.isDate

Returns: bool
Returns: bool

this.isFactor

Full Usage: this.isFactor

Returns: bool
Returns: bool

this.isFreeText

Full Usage: this.isFreeText

Returns: bool
Returns: bool

this.isInput

Full Usage: this.isInput

Returns: bool
Returns: bool

this.isOutput

Full Usage: this.isOutput

Returns: bool
Returns: bool

this.isParameter

Full Usage: this.isParameter

Returns: bool
Returns: bool

this.isPerformer

Full Usage: this.isPerformer

Returns: bool
Returns: bool

this.isProtocolColumn

Full Usage: this.isProtocolColumn

Returns: bool
Returns: bool

this.isProtocolDescription

Full Usage: this.isProtocolDescription

Returns: bool
Returns: bool

this.isProtocolREF

Full Usage: this.isProtocolREF

Returns: bool
Returns: bool

this.isProtocolType

Full Usage: this.isProtocolType

Returns: bool
Returns: bool

this.isProtocolUri

Full Usage: this.isProtocolUri

Returns: bool
Returns: bool

this.isProtocolVersion

Full Usage: this.isProtocolVersion

Returns: bool
Returns: bool

Type something to start searching.