Logo ProcessCore

Tables Type

Ordered, named collection of Table objects backed by a Dataset. Groups processes by name: each unique process name in the dataset becomes one Table.

Constructors

Constructor Description

Tables(dataset)

Full Usage: Tables(dataset)

Parameters:
Returns: Tables
dataset : Dataset
Returns: Tables

Instance members

Instance member Description

this.AddColumn

Full Usage: this.AddColumn

Parameters:

Add a column to the named table.

tableName : string
header : CompositeHeader
?cells : ResizeArray<CompositeCell>

this.AddRow

Full Usage: this.AddRow

Parameters:
    tableName : string
    ?cells : ResizeArray<CompositeCell>
    ?rowIndex : int

Add a row to the named table.

tableName : string
?cells : ResizeArray<CompositeCell>
?rowIndex : int

this.AddTable

Full Usage: this.AddTable

Parameters:
    name : string

Returns: Table

Add a new empty table (creates no processes until rows are added). Fails if a table with that name already exists.

name : string
Returns: Table

this.GetTable

Full Usage: this.GetTable

Parameters:
    name : string

Returns: Table

Get a table by name. Raises if not found.

name : string
Returns: Table

this.GetTableAt

Full Usage: this.GetTableAt

Parameters:
    index : int

Returns: Table

Get a table by index.

index : int
Returns: Table

this.GetTables

Full Usage: this.GetTables

Returns: ResizeArray<Table>

Build the live list of Table objects by grouping dataset processes by name.

Returns: ResizeArray<Table>

this.RemoveColumn

Full Usage: this.RemoveColumn

Parameters:

Remove a column from the named table.

tableName : string
header : CompositeHeader

this.RemoveRow

Full Usage: this.RemoveRow

Parameters:
    tableName : string
    rowIndex : int

Remove a row from the named table.

tableName : string
rowIndex : int

this.RemoveTable

Full Usage: this.RemoveTable

Parameters:
    name : string

Remove all processes belonging to the named table from the dataset.

name : string

this.RenameTable

Full Usage: this.RenameTable

Parameters:
    oldName : string
    newName : string

Rename all processes belonging to `oldName` to `newName`.

oldName : string
newName : string

this.TableCount

Full Usage: this.TableCount

Returns: int

Number of tables (= number of distinct process names).

Returns: int

this.TableNames

Full Usage: this.TableNames

Returns: ResizeArray<string>

Names of all tables in order.

Returns: ResizeArray<string>

this.TryGetTable

Full Usage: this.TryGetTable

Parameters:
    name : string

Returns: Table option

Try to get a table by name.

name : string
Returns: Table option

Type something to start searching.