Data Type
Data file or selected fragment produced or consumed by processes. schema.org/MediaObject or File
Constructors
| Constructor |
Description
|
Full Usage:
Data(path, ?selector, ?selectorFormat, ?encodingFormat, ?additionalType, ?hasPart, ?additionalProperty)
Parameters:
string
?selector : string
?selectorFormat : string
?encodingFormat : string
?additionalType : string
?hasPart : Data seq
?additionalProperty : Annotation seq
Returns: Data
|
|
Instance members
| Instance member |
Description
|
|
|
|
|
|
|
Full Usage:
this.AdditionalType
Returns: string option
|
Decoration discriminator (e.g. "Raw Data")
|
Full Usage:
this.AllAnnotations
Parameters:
ResizeArray<Process>
Returns: ResizeArray<Annotation>
|
All Annotations from all sources connected to this data node through the graph.
|
|
|
|
|
|
|
|
|
Full Usage:
this.DownstreamAnnotations
Parameters:
string
?scope : ResizeArray<Process>
Returns: ResizeArray<Annotation>
|
|
|
|
|
|
|
|
|
|
Full Usage:
this.EncodingFormat
Returns: string option
|
MIME type
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
this.Name
Returns: string
|
|
|
|
Full Usage:
this.Path
Returns: string
|
|
|
|
|
|
Full Usage:
this.RecipeParameters
Parameters:
ResizeArray<Process>
Returns: ResizeArray<FormalParameter>
|
All FormalParameters from recipes connected to this data node.
|
|
|
|
|
|
|
Full Usage:
this.Selector
Returns: string option
|
Fragment selector
|
Full Usage:
this.SelectorFormat
Returns: string option
|
Formal description of the selector syntax (e.g. RFC 7111)
|
|
|
Full Usage:
this.UpstreamAnnotations
Parameters:
string
?scope : ResizeArray<Process>
Returns: ResizeArray<Annotation>
|
|
|
|
|
|
|
|
|
ProcessCore