Data Type
Data file produced or consumed by processes. schema.org/MediaObject or File
Constructors
| Constructor |
Description
|
Full Usage:
Data(path, ?selector, ?selectorFormat, ?encodingFormat, ?additionalType, ?additionalProperty)
Parameters:
string
?selector : string
?selectorFormat : string
?encodingFormat : string
?additionalType : string
?additionalProperty : PropertyValue seq
Returns: Data
|
|
Instance members
| Instance member |
Description
|
|
|
|
|
Full Usage:
this.AdditionalType
Returns: string option
|
Decoration discriminator (e.g. "Raw Data")
|
Full Usage:
this.AllConnectedNodes
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<IONode>
|
All IONodes connected to this data node through the graph.
|
Full Usage:
this.AllConnectedProcesses
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<LabProcess>
|
All processes connected to this data node through the graph.
|
Full Usage:
this.AllPropertyValues
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<PropertyValue>
|
All PropertyValues from all sources connected to this data node through the graph.
|
Full Usage:
this.ConnectedData
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Data>
|
All Data nodes connected to this data node through the graph.
|
Full Usage:
this.ConnectedMaterials
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Material>
|
All Material nodes connected to this data node through the graph.
|
Full Usage:
this.DownstreamData
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Data>
|
|
Full Usage:
this.DownstreamMaterials
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Material>
|
|
Full Usage:
this.DownstreamNodes
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<IONode>
|
|
Full Usage:
this.DownstreamProcesses
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<LabProcess>
|
|
Full Usage:
this.DownstreamPropertyValues
Parameters:
string
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<PropertyValue>
|
|
Full Usage:
this.EncodingFormat
Returns: string option
|
MIME type
|
Full Usage:
this.FinalNodes
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<IONode>
|
|
|
Processes for which this data node is an input (back-edge)
|
|
|
|
|
|
Processes for which this data node is an output (back-edge)
|
Full Usage:
this.Path
Returns: string
|
|
Full Usage:
this.PathsThrough
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Path>
|
All maximal Paths that pass through this data node.
|
Full Usage:
this.Processes
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<LabProcess>
|
All in-scope processes in which this data node appears as an input or output.
|
Full Usage:
this.ProtocolParameters
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<FormalParameter>
|
All FormalParameters from protocols connected to this data node.
|
|
|
Full Usage:
this.RootNodes
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<IONode>
|
|
Full Usage:
this.Selector
Returns: string option
|
Fragment selector
|
Full Usage:
this.SelectorFormat
Returns: string option
|
Formal description of the selector syntax (e.g. RFC 7111)
|
Full Usage:
this.UpstreamData
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Data>
|
|
Full Usage:
this.UpstreamMaterials
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Material>
|
|
Full Usage:
this.UpstreamNodes
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<IONode>
|
|
Full Usage:
this.UpstreamProcesses
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<LabProcess>
|
|
Full Usage:
this.UpstreamPropertyValues
Parameters:
string
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<PropertyValue>
|
|
ProcessCore