ProcessCore.Helper Namespace
| Modules | Description |
|
This module contains helper functions to handle study/assay/investigation identifiers in an unsafe, forced way. |
|
|
|
|
|
|
|
|
|
|
|
This module contains unified regex patterns and matching functions to parse isa tab column headers to BuildingBlock information. |
|
|
|
ProcessCore