Workflow Module
Workflow only contains "FileName" in isa.workflow.xlsx. To unify naming in our model, on read-in we transform fileName to identifier and reverse for writing.
Functions and values
| Function or value |
Description
|
Full Usage:
Workflow.cwlFileNameFromIdentifier identifier
Parameters:
string
-
Any correct workflow identifier
Returns: string
|
On writing a cwl file we unify our output to a relative path to ARC root. So: `workflows/workflowIdentifier/workflow.cwl`.
|
Full Usage:
Workflow.datamapFileNameFromIdentifier identifier
Parameters:
string
-
Any correct workflow identifier
Returns: string
|
On writing a xlsx file we unify our output to a relative path to ARC root. So: `workflows/workflowIdentifier/isa.datamap.xlsx`.
|
Full Usage:
Workflow.fileNameFromIdentifier identifier
Parameters:
string
-
Any correct workflow identifier
Returns: string
|
On writing a xlsx file we unify our output to a relative path to ARC root. So: `workflows/workflowIdentifier/isa.workflow.xlsx`.
|
Full Usage:
Workflow.identifierFromFileName fileName
Parameters:
string
-
FileName as written in isa.workflow.xlsx metadata sheet
Returns: string
|
On read-in the FileName can be any combination of "workflows" (workflow folder name), workflowIdentifier and "isa.workflow.xlsx" (the actual file name). This functions extracts workflowIdentifier from any of these combinations and returns it.
|
Full Usage:
Workflow.tryCwlFileNameFromIdentifier identifier
Parameters:
string
-
Any correct workflow identifier
Returns: string option
|
On writing a cwl file we unify our output to a relative path to ARC root. So: `workflows/workflowIdentifier/workflow.cwl`.
|
Full Usage:
Workflow.tryDatamapFileNameFromIdentifier identifier
Parameters:
string
-
Any correct workflow identifier
Returns: string option
|
On writing a xlsx file we unify our output to a relative path to ARC root. So: `workflows/workflowIdentifier/isa.datamap.xlsx`.
|
Full Usage:
Workflow.tryFileNameFromIdentifier identifier
Parameters:
string
-
Any correct workflow identifier
Returns: string option
|
On writing a xlsx file we unify our output to a relative path to ARC root. So: `workflows/workflowIdentifier/isa.workflow.xlsx`.
|
Full Usage:
Workflow.tryIdentifierFromFileName fileName
Parameters:
string
-
FileName as written in isa.workflow.xlsx metadata sheet
Returns: string option
|
On read-in the FileName can be any combination of "workflows" (workflow folder name), workflowIdentifier and "isa.workflow.xlsx" (the actual file name). This functions extracts workflowIdentifier from any of these combinations and returns it.
|
ProcessCore