Regex Module
This module contains unified regex patterns and matching functions to parse isa tab column headers to BuildingBlock information.
Nested modules
| Modules | Description |
|
|
|
|
|
Functions and values
| Function or value |
Description
|
Full Usage:
getTermAnnotationShortString str
Parameters:
string
Returns: string
|
Parses 'str' to term accession and returns it in the format "termsourceref:localtan". Exmp.: "MS:000001"
|
Full Usage:
tryGetTermAnnotationShortString str
Parameters:
string
Returns: string option
|
Tries to parse 'str' to term accession and returns it in the format `Some "termsourceref:localtan"`. Exmp.: `Some "MS:000001"`
|
Full Usage:
tryParseCharacteristicColumnHeader input
Parameters:
string
Returns: string option
|
Matches a "Characteristic [Term]" or "Characteristics [Term]" or "Characteristics Value [Term]" column header and returns the Term string.
|
Full Usage:
tryParseComponentColumnHeader input
Parameters:
string
Returns: string option
|
Matches a "Component [Term]" or "Characteristics [Term]" or "Component Value [Term]" column header and returns the Term string.
|
Full Usage:
tryParseExcelNumberFormat headerStr
Parameters:
string
Returns: string option
|
This function is used to parse Excel numberFormat string to term name. **Example 1:** "0.00 "degree Celsius"" --> "degree Celsius"
|
Full Usage:
tryParseFactorColumnHeader input
Parameters:
string
Returns: string option
|
Matches a "Factor [Term]" or "Factor Value [Term]" column header and returns the Term string.
|
Full Usage:
tryParseIOTypeHeader headerStr
Parameters:
string
Returns: string option
|
This function is used to match both Input and Output columns and capture the IOType as `iotype` group. **Example 1:** "Input [Sample]" --> "Sample"
|
Full Usage:
tryParseInputColumnHeader input
Parameters:
string
Returns: string option
|
Matches a "Input [InputType]" column header and returns the InputType as string.
|
Full Usage:
tryParseOutputColumnHeader input
Parameters:
string
Returns: string option
|
Matches a "Output [OutputType]" column header and returns the OutputType as string.
|
Full Usage:
tryParseParameterColumnHeader input
Parameters:
string
Returns: string option
|
Matches a "Parameter [Term]" or "Parameter Value [Term]" column header and returns the Term string.
|
Full Usage:
tryParseReferenceColumnHeader str
Parameters:
string
Returns: (type) option
|
|
Full Usage:
tryParseTANColumnHeader input
Parameters:
string
Returns: (type) option
|
Matches a "Term Accession Number (ShortTerm)" column header and returns the ShortTerm as Term Source Ref and Annotation Number. Example: "Term Accession Number (MS:1003022)" --> term source ref: "MS"; annotation number: "1003022"
|
Full Usage:
tryParseTSRColumnHeader input
Parameters:
string
Returns: (type) option
|
Matches a "Term Source REF (ShortTerm)" column header and returns the ShortTerm as Term Source Ref and Annotation Number. Example: "Term Source REF (MS:1003022)" --> term source ref: "MS"; annotation number: "1003022"
|
Full Usage:
tryParseTermAnnotation str
Parameters:
string
Returns: (type) option
|
This function can be used to extract `IDSPACE:LOCALID` (or: `Term Accession`) from Swate header strings or obofoundry conform URI strings. **Example 1:** "http://purl.obolibrary.org/obo/GO_000001" --> "GO:000001" **Example 2:** "Term Source REF (NFDI4PSO:0000064)" --> "NFDI4PSO:0000064"
|
Full Usage:
tryParseTermAnnotationShort str
Parameters:
string
Returns: (type) option
|
|
Full Usage:
tryParseTermColumn input
Parameters:
string
Returns: (type) option
|
Matches any column header starting with some text, followed by one whitespace and a term name inside squared brackets.
|
Full Usage:
tryParseUnitColumnHeader input
Parameters:
string
Returns: string option
|
Matches a "Unit" column header.
|
ProcessCore