Logo ProcessCore

Regex Module

Nested modules

Modules Description

ActivePatterns

Pattern

Functions and values

Function or value Description

getTermAnnotationShortString str

Full Usage: getTermAnnotationShortString str

Parameters:
    str : string

Returns: string

Parses 'str' to term accession and returns it in the format "termsourceref:localtan". Exmp.: "MS:000001"

str : string
Returns: string

tryGetTermAnnotationShortString str

Full Usage: tryGetTermAnnotationShortString str

Parameters:
    str : string

Returns: string option

Tries to parse 'str' to term accession and returns it in the format `Some "termsourceref:localtan"`. Exmp.: `Some "MS:000001"`

str : string
Returns: string option

tryParseTermAnnotation str

Full Usage: tryParseTermAnnotation str

Parameters:
    str : string

Returns: (type) option

This function can be used to extract `IDSPACE:LOCALID` (or: `Term Accession`) from Swate header strings or obofoundry conform URI strings. **Example 1:** "http://purl.obolibrary.org/obo/GO_000001" --> "GO:000001" **Example 2:** "Term Source REF (NFDI4PSO:0000064)" --> "NFDI4PSO:0000064"

str : string
Returns: (type) option

tryParseTermAnnotationShort str

Full Usage: tryParseTermAnnotationShort str

Parameters:
    str : string

Returns: (type) option
str : string
Returns: (type) option

Type something to start searching.