ActivePatterns Module
Active patterns
| Active pattern |
Description
|
Full Usage:
(|AutoGeneratedTableName|_|) input
Parameters:
string
Returns: int option
|
Matches auto-generated readable table names. Mainly used in ArcAssay.addTable(). Default tables will get such a name. Will match "New Table 10" and return the number `10`.
|
Full Usage:
(|CharacteristicColumnHeader|_|) input
Parameters:
string
Returns: string option
|
Matches a "Characteristic [Term]" or "Characteristics [Term]" or "Characteristics Value [Term]" column header and returns the Term string.
|
Full Usage:
(|Comment|_|) input
Parameters:
string
Returns: string option
|
|
Full Usage:
(|ComponentColumnHeader|_|) input
Parameters:
string
Returns: string option
|
Matches a "Component [Term]" or "Component Value [Term]" column header and returns the Term string.
|
Full Usage:
(|FactorColumnHeader|_|) input
Parameters:
string
Returns: string option
|
Matches a "Factor [Term]" or "Factor Value [Term]" column header and returns the Term string.
|
Full Usage:
(|InputColumnHeader|_|) input
Parameters:
string
Returns: string option
|
Matches a "Input [InputType]" column header and returns the InputType as string.
|
Full Usage:
(|OutputColumnHeader|_|) input
Parameters:
string
Returns: string option
|
Matches a "Output [OutputType]" column header and returns the OutputType as string.
|
Full Usage:
(|ParameterColumnHeader|_|) input
Parameters:
string
Returns: string option
|
Matches a "Parameter [Term]" or "Parameter Value [Term]" column header and returns the Term string.
|
Full Usage:
(|ReferenceColumnHeader|_|) input
Parameters:
string
Returns: (type) option
|
Matches any column header starting with some text, followed by one whitespace and a term name inside squared brackets.
|
Full Usage:
(|Regex|_|) pattern input
Parameters:
string
input : string
Returns: Match option
|
Matches, if the input string matches the given regex pattern.
|
Full Usage:
(|TANColumnHeader|_|) input
Parameters:
string
Returns: (type) option
|
Matches a "Term Accession Number (ShortTerm)" column header and returns the ShortTerm as Term Source Ref and Annotation Number. Example: "Term Accession Number (MS:1003022)" --> term source ref: "MS"; annotation number: "1003022"
|
Full Usage:
(|TSRColumnHeader|_|) input
Parameters:
string
Returns: (type) option
|
Matches a "Term Source REF (ShortTerm)" column header and returns the ShortTerm as Term Source Ref and Annotation Number. Example: "Term Source REF (MS:1003022)" --> term source ref: "MS"; annotation number: "1003022"
|
Full Usage:
(|TermAnnotationShort|_|) input
Parameters:
string
Returns: (type) option
|
Matches a short term string and returns the term source ref and the annotation number strings. Example: "MS:1003022" --> term source ref: "MS"; annotation number: "1003022"
|
Full Usage:
(|TermAnnotation|_|) input
Parameters:
string
Returns: (type) option
|
Matches a term string (either short or URI) and returns the term source ref and the annotation number strings. Example 1: "MS:1003022" --> term source ref: "MS"; annotation number: "1003022" Example 2: "http://purl.obolibrary.org/obo/MS_1003022" --> term source ref: "MS"; annotation number: "1003022"
|
Full Usage:
(|TermColumn|_|) input
Parameters:
string
Returns: (type) option
|
Matches any column header starting with some text, followed by one whitespace and a term name inside squared brackets.
|
Full Usage:
(|UnitColumnHeader|_|) input
Parameters:
string
Returns: string option
|
Matches a "Unit" column header.
|
ProcessCore