Logo ProcessCore

ActivePatterns Module

Active patterns

Active pattern Description

(|Regex|_|) pattern input

Full Usage: (|Regex|_|) pattern input

Parameters:
    pattern : string
    input : string

Returns: Match option

Matches, if the input string matches the given regex pattern.

pattern : string
input : string
Returns: Match option

(|TermAnnotationShort|_|) input

Full Usage: (|TermAnnotationShort|_|) input

Parameters:
    input : string

Returns: (type) option

Matches a short term string and returns the term source ref and the annotation number strings. Example: "MS:1003022" --> term source ref: "MS"; annotation number: "1003022"

input : string
Returns: (type) option

(|TermAnnotation|_|) input

Full Usage: (|TermAnnotation|_|) input

Parameters:
    input : string

Returns: (type) option

Matches a term string (either short or URI) and returns the term source ref and the annotation number strings. Example 1: "MS:1003022" --> term source ref: "MS"; annotation number: "1003022" Example 2: "http://purl.obolibrary.org/obo/MS_1003022" --> term source ref: "MS"; annotation number: "1003022"

input : string
Returns: (type) option

Type something to start searching.