ActivePatterns Module
Active patterns
| Active pattern |
Description
|
Full Usage:
(|Regex|_|) pattern input
Parameters:
string
input : string
Returns: Match option
|
Matches, if the input string matches the given regex pattern.
|
Full Usage:
(|TermAnnotationShort|_|) input
Parameters:
string
Returns: (type) option
|
Matches a short term string and returns the term source ref and the annotation number strings. Example: "MS:1003022" --> term source ref: "MS"; annotation number: "1003022"
|
Full Usage:
(|TermAnnotation|_|) input
Parameters:
string
Returns: (type) option
|
Matches a term string (either short or URI) and returns the term source ref and the annotation number strings. Example 1: "MS:1003022" --> term source ref: "MS"; annotation number: "1003022" Example 2: "http://purl.obolibrary.org/obo/MS_1003022" --> term source ref: "MS"; annotation number: "1003022"
|
ProcessCore