Pattern Module
Nested modules
| Modules | Description |
|
|
Functions and values
| Function or value |
Description
|
Full Usage:
AutoGeneratedTableName
Returns: string
|
This pattern is used to match auto-generated table names. Mainly used in ArcAssay.addTable(). Default tables will get such a name. Will match "New Table 10" and will capture the number as `number` group.
|
Full Usage:
CommentPattern
Returns: string
|
This pattern is used to match Comment column and capture the comment key as `commentKey` group.
|
Full Usage:
ExcelNumberFormat
Returns: string
|
Used to get unit name from Excel numberFormat: 0.00 "degree Celsius" --> degree Celsius
|
Full Usage:
IOTypePattern
Returns: string
|
This pattern is used to match both Input and Output columns and capture the IOType as `iotype` group.
|
Full Usage:
IdPattern
Returns: string
|
This pattern is only used to remove any leftover #id attributes from previous Swate version. `"Parameter [biological replicate#2]"` This #id is deprecated but the pattern can still be used to remove any from files. Was deprecated before 2023.
|
Full Usage:
InputPattern
Returns: string
|
This pattern is used to match Input column and capture the IOType as `iotype` group.
|
Full Usage:
OutputPattern
Returns: string
|
This pattern is used to match Output column and capture the IOType as `iotype` group.
|
Full Usage:
ReferenceColumnPattern
Returns: string
|
Hits Term Source REF and Term Accession Number column headers Example 1: "Term Source REF (MS:1003022)" Example 2: "Term Accession Number (MS:1003022)" the id part "MS:1003022" is captured as `id` group.
|
Full Usage:
SquaredBracketsTermNamePattern
Returns: string
|
This pattern captures characters between squared brackets, without id: Parameter [biological replicate#2] -> [biological replicate] TODO: Could be redesigned to use capture groups, then it could return inner without brackets
|
Full Usage:
TermAccessionNumberColumnPattern
Returns: string
|
Hits Term Source REF column header Example 1: "Term Accession Number (MS:1003022)" the id part "MS:1003022" is captured as `id` group.
|
Full Usage:
TermAnnotationShortPattern
Returns: string
|
Hits term accession, without id: ENVO:01001831
|
Full Usage:
TermAnnotationURIPattern
Returns: string
|
Regex pattern is designed to hit only Foundry-compliant URIs.
|
Full Usage:
TermAnnotationURIPattern_MS_RO_PO
Returns: string
|
Watch this closely, this could hit some edge cases we do not want to cover.
|
Full Usage:
TermAnnotationURIPattern_lessRestrictive
Returns: string
|
Watch this closely, this could hit some edge cases we do not want to cover.
|
Full Usage:
TermAnnotationURIPattern_stringTSR
Returns: string
|
|
Full Usage:
TermColumnPattern
Returns: string
|
This pattern matches any column header starting with some text, followed by one whitespace and a term name inside squared brackets. Captures column type as named group: "termcolumntype" (e.g. Component, Characteristic .. ). Captures term name as named group: "termname" (e.g. instrument model). Exmp. 1: Parameter [instrument model] --> termcolumntype: Parameter; termname: instrument model Exmp. 2: Characteristic [species] --> termcolumntype: Characteristic; termname: species
|
Full Usage:
TermSourceREFColumnPattern
Returns: string
|
Hits Term Accession Number column header Example 1: "Term Source REF (MS:1003022)" the id part "MS:1003022" is captured as `id` group.
|
Full Usage:
UnitPattern
Returns: string
|
Hits Unit column header
|
Full Usage:
handleGroupPatterns pattern
Parameters:
string
Returns: string
|
|
ProcessCore