Logo ProcessCore

Pattern Module

Nested modules

Modules Description

MatchGroups

Functions and values

Function or value Description

TermAnnotationShortPattern

Full Usage: TermAnnotationShortPattern

Returns: string

Hits term accession, without id: ENVO:01001831

Returns: string

TermAnnotationURIPattern

Full Usage: TermAnnotationURIPattern

Returns: string

Regex pattern is designed to hit only Foundry-compliant URIs.

Returns: string

TermAnnotationURIPattern_MS_RO_PO

Full Usage: TermAnnotationURIPattern_MS_RO_PO

Returns: string

Watch this closely, this could hit some edge cases we do not want to cover.

Returns: string

TermAnnotationURIPattern_lessRestrictive

Full Usage: TermAnnotationURIPattern_lessRestrictive

Returns: string

Watch this closely, this could hit some edge cases we do not want to cover.

Returns: string

handleGroupPatterns pattern

Full Usage: handleGroupPatterns pattern

Parameters:
    pattern : string

Returns: string
pattern : string
Returns: string

Type something to start searching.