Pattern Module
Nested modules
| Modules | Description |
|
|
Functions and values
| Function or value |
Description
|
Full Usage:
TermAnnotationShortPattern
Returns: string
|
Hits term accession, without id: ENVO:01001831
|
Full Usage:
TermAnnotationURIPattern
Returns: string
|
Regex pattern is designed to hit only Foundry-compliant URIs.
|
Full Usage:
TermAnnotationURIPattern_MS_RO_PO
Returns: string
|
Watch this closely, this could hit some edge cases we do not want to cover.
|
Full Usage:
TermAnnotationURIPattern_lessRestrictive
Returns: string
|
Watch this closely, this could hit some edge cases we do not want to cover.
|
Full Usage:
handleGroupPatterns pattern
Parameters:
string
Returns: string
|
|
ProcessCore