Material Type
Input or output biological, chemical, or digital material in the process graph. bioschemas.org/Sample
Constructors
| Constructor |
Description
|
Full Usage:
Material(name, ?additionalType, ?additionalProperty)
Parameters:
string
?additionalType : string
?additionalProperty : PropertyValue seq
Returns: Material
|
|
Instance members
| Instance member |
Description
|
|
|
|
|
Full Usage:
this.AdditionalType
Returns: string option
|
Decoration discriminator (e.g. "Sample", "Source")
|
Full Usage:
this.AllConnectedNodes
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<IONode>
|
All IONodes connected to this material through the graph.
|
Full Usage:
this.AllConnectedProcesses
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<LabProcess>
|
All processes connected to this material through the graph.
|
Full Usage:
this.AllPropertyValues
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<PropertyValue>
|
All PropertyValues from all sources connected to this material through the graph.
|
Full Usage:
this.ConnectedData
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Data>
|
All Data nodes connected to this material through the graph.
|
Full Usage:
this.ConnectedMaterials
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Material>
|
All Material nodes connected to this material through the graph.
|
Full Usage:
this.DownstreamData
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Data>
|
|
Full Usage:
this.DownstreamMaterials
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Material>
|
|
Full Usage:
this.DownstreamNodes
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<IONode>
|
|
Full Usage:
this.DownstreamProcesses
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<LabProcess>
|
|
Full Usage:
this.DownstreamPropertyValues
Parameters:
string
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<PropertyValue>
|
|
Full Usage:
this.FinalNodes
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<IONode>
|
|
|
Processes for which this material is an input (back-edge)
|
|
|
|
|
Full Usage:
this.Name
Returns: string
|
|
|
Processes for which this material is an output (back-edge)
|
Full Usage:
this.PathsThrough
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Path>
|
All maximal Paths that pass through this material.
|
Full Usage:
this.Processes
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<LabProcess>
|
All in-scope processes in which this material appears as an input or output.
|
Full Usage:
this.ProtocolParameters
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<FormalParameter>
|
All FormalParameters from protocols connected to this material.
|
|
|
Full Usage:
this.RootNodes
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<IONode>
|
|
Full Usage:
this.UpstreamData
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Data>
|
|
Full Usage:
this.UpstreamMaterials
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<Material>
|
|
Full Usage:
this.UpstreamNodes
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<IONode>
|
|
Full Usage:
this.UpstreamProcesses
Parameters:
ResizeArray<LabProcess>
Returns: ResizeArray<LabProcess>
|
|
Full Usage:
this.UpstreamPropertyValues
Parameters:
string
?scope : ResizeArray<LabProcess>
Returns: ResizeArray<PropertyValue>
|
|
ProcessCore