Sample Type
Input or output biological, chemical, or digital sample in the process graph. bioschemas.org/Sample
Constructors
| Constructor |
Description
|
Full Usage:
Sample(name, ?additionalType, ?additionalProperty)
Parameters:
string
?additionalType : string
?additionalProperty : Annotation seq
Returns: Sample
|
|
Instance members
| Instance member |
Description
|
|
|
|
|
Full Usage:
this.AdditionalType
Returns: string option
|
Decoration discriminator (e.g. "Sample", "Source")
|
Full Usage:
this.AllAnnotations
Parameters:
ResizeArray<Process>
Returns: ResizeArray<Annotation>
|
All Annotations from all sources connected to this sample through the graph.
|
|
|
|
|
|
|
|
|
Full Usage:
this.DownstreamAnnotations
Parameters:
string
?scope : ResizeArray<Process>
Returns: ResizeArray<Annotation>
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
this.Name
Returns: string
|
|
|
|
|
|
|
|
Full Usage:
this.RecipeParameters
Parameters:
ResizeArray<Process>
Returns: ResizeArray<FormalParameter>
|
All FormalParameters from recipes connected to this sample.
|
|
|
|
|
Full Usage:
this.UpstreamAnnotations
Parameters:
string
?scope : ResizeArray<Process>
Returns: ResizeArray<Annotation>
|
|
|
|
|
|
|
|
|
ProcessCore