List Module
Functions and values
| Function or value |
Description
|
Full Usage:
groupWhen f list
Parameters:
'a -> bool
list : 'a list
Returns: 'a list list
Type parameters: 'a |
Iterates over elements of the input list and groups adjacent elements.
A new group is started when the specified predicate holds about the element
of the list (and at the beginning of the iteration).
For example:
List.groupWhen isOdd [3;3;2;4;1;2] = [[3]; [3; 2; 4]; [1; 2]]
|
ProcessCore