CompositeHeader Type
Typed column header. Carries the column role and, for annotation columns, the ontology term identifying what is being described.
Union cases
| Union case |
Description
|
|
|
Full Usage:
Comment string
Parameters:
string
|
|
|
|
Full Usage:
Date
|
|
|
|
Full Usage:
FreeText string
Parameters:
string
|
|
|
|
|
|
|
|
Full Usage:
Performer
|
|
Full Usage:
ProtocolDescription
|
|
Full Usage:
ProtocolREF
|
|
Full Usage:
ProtocolType
|
|
Full Usage:
ProtocolUri
|
|
Full Usage:
ProtocolVersion
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.GetColumnAccessionShort
Returns: string
|
This function gets the associated term accession for term columns.
|
Full Usage:
this.GetFeaturedColumnAccession
Returns: string
|
This function gets the associated term accession for featured columns. It contains the hardcoded term accessions.
|
Full Usage:
this.IsCharacteristic
Returns: bool
|
|
Full Usage:
this.IsComment
Returns: bool
|
|
Full Usage:
this.IsComponent
Returns: bool
|
|
Full Usage:
this.IsCvParamColumn
Returns: bool
|
|
Full Usage:
this.IsDataColumn
Returns: bool
|
|
Full Usage:
this.IsDate
Returns: bool
|
|
Full Usage:
this.IsFactor
Returns: bool
|
|
Full Usage:
this.IsFeaturedColumn
Returns: bool
|
Is true if the Building Block type is a FeaturedColumn. A FeaturedColumn can be abstracted by Parameter/Factor/Characteristic and describes one common usecase of either. Such a block will contain TSR and TAN and can be used for directed Term search.
|
Full Usage:
this.IsFreeText
Returns: bool
|
|
Full Usage:
this.IsIOType
Returns: bool
|
|
Full Usage:
this.IsInput
Returns: bool
|
|
Full Usage:
this.IsOutput
Returns: bool
|
|
Full Usage:
this.IsParameter
Returns: bool
|
|
Full Usage:
this.IsPerformer
Returns: bool
|
|
Full Usage:
this.IsProtocolDescription
Returns: bool
|
|
Full Usage:
this.IsProtocolREF
Returns: bool
|
|
Full Usage:
this.IsProtocolType
Returns: bool
|
|
Full Usage:
this.IsProtocolUri
Returns: bool
|
|
Full Usage:
this.IsProtocolVersion
Returns: bool
|
|
Full Usage:
this.IsSingleColumn
Returns: bool
|
Is true if the Building Block type is parsed to a single column. This can be any input, output column, as well as for example: `ProtocolREF` and `Performer` with FreeText body cells.
|
Full Usage:
this.IsTermColumn
Returns: bool
|
Is true if this Building Block type is a TermColumn. The name "TermColumn" refers to all columns with the syntax "Parameter/Factor/etc [TERM-NAME]" and featured columns such as Protocol Type as these are also represented as a triplet of MainColumn-TSR-TAN.
|
Full Usage:
this.IsUnique
Returns: bool
|
|
|
|
|
|
|
|
Full Usage:
this.isCharacteristic
Returns: bool
|
|
Full Usage:
this.isComment
Returns: bool
|
|
Full Usage:
this.isComponent
Returns: bool
|
|
Full Usage:
this.isDate
Returns: bool
|
|
Full Usage:
this.isFactor
Returns: bool
|
|
Full Usage:
this.isFreeText
Returns: bool
|
|
Full Usage:
this.isInput
Returns: bool
|
|
Full Usage:
this.isOutput
Returns: bool
|
|
Full Usage:
this.isParameter
Returns: bool
|
|
Full Usage:
this.isPerformer
Returns: bool
|
|
Full Usage:
this.isProtocolColumn
Returns: bool
|
|
Full Usage:
this.isProtocolDescription
Returns: bool
|
|
Full Usage:
this.isProtocolREF
Returns: bool
|
|
Full Usage:
this.isProtocolType
Returns: bool
|
|
Full Usage:
this.isProtocolUri
Returns: bool
|
|
Full Usage:
this.isProtocolVersion
Returns: bool
|
|
ProcessCore